@@ -32,12 +32,13 @@ summary_VPA <- function(Assessment) {
 
   output <- list(model = "Virtual Population Analysis (VPA)",
                  current_status = current_status, input_parameters = input_parameters,
-                 derived_quantities = derived, model_estimates = model_estimates)
+                 derived_quantities = derived, model_estimates = model_estimates,
+                 log_likelihood = matrix(NLL, ncol = 1, dimnames = list(names(NLL), "Neg.LL")))
   return(output)
 }
 class(VPA) <- "Assessment"
 
-rmd_VPA <- function(Assessment) {
+rmd_VPA <- function(Assessment, ...) {
   ss <- rmd_summary("Virtual Population Analysis (VPA)")
 
   # Life History
