@@ -2,21 +2,24 @@
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
 knitr::opts_chunk$set(dpi=85)
 options(width = 650)
-library(DLMtool)
-library(MSEtool)
 
 ## ---- eval = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  DLMtool::userguide()
 #  DLMtool::cheatsheets()
+#  
 #  MSEtool::userguide()
 
-## ---- eval = TRUE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-library(DLMtool)    # load DLMtool library
-# DLMextra()        # download lots of cool DLMtool/MSEtool objects from GitHub
-# library(DLMextra) # load all those objects
-library(MSEtool)    # load MSEtool (data rich MPs, MOM object class etc)
-setup()             # set up a cluster for parallel processing
+## ---- eval = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  library(DLMtool)    # load DLMtool library
+#  DLMextra()          # download lots of cool DLMtool/MSEtool objects from GitHub
+#  library(DLMextra)   # load all those objects
+#  library(MSEtool)    # load MSEtool (data rich MPs, MOM object class etc)
+#  setup()             # set up a cluster for parallel processing
 
+## ---- echo = FALSE, eval = TRUE, message = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+library(MSEtool)
+
+## ---- eval = TRUE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 slotNames('MOM')    # what slots are there in an MOM object
 class?MOM           # check out the help file on MOM objects
 
@@ -70,7 +73,7 @@ CatchFrac <- list(
 CatchFrac[[1]]
 
 
-## ---- eval = TRUE, fig.width=5, fig.height=5----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- eval = TRUE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ages <- 1:60
 bf_M <- mean(Bluefin_tuna@M)          # natural mortality rate
 bf_Linf <- mean(Bluefin_tuna@Linf)    # asymptotic length
@@ -90,19 +93,20 @@ dat <- data.frame(M_2,B_1)
 bfB_hM <- lm(M_2~B_1,dat=dat) # a linear model predicting M for stock 2 from biomass B for stock 1
 summary(bfB_hM)
 
-plot(dat$B_1, dat$M_2,pch=19)
-lines(dat$B_1, predict(bfB_hM,newdat=dat),col='red')
-points(dat$B_1, simulate(bfB_hM,nsim=1,newdat=dat)[,1],col='green')
-legend('topleft',legend=c("made up data","best fit","simulated"),text.col=c('black','red','green'))
-
 Rel <- list(bfB_hM)
 
+## ---- eval = TRUE, fig.width=6, fig.height=5----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+plot(dat$B_1, dat$M_2,pch=19, xlab = "Bluefin biomass", ylab = "Herring natural mortality")
+lines(dat$B_1, predict(bfB_hM,newdat=dat), col = 'red', lwd = 2)
+points(dat$B_1, simulate(bfB_hM,nsim=1,newdat=dat)[, 1], col = 'green')
+legend('topleft',legend = c("made up data", "best fit", "simulated"), text.col = c('black','red','green'))
 
-## ---- eval = TRUE,  fig.width=9, fig.height=7---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-
+## ---- echo = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 MOM_BH <- new('MOM', Stocks, Fleets, Obs, Imps, CatchFrac, Rel=Rel, nsim=nsim)
-plot(MOM_BH)
 
+## ---- eval = FALSE,  fig.width=9, fig.height=7--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  MOM_BH <- new('MOM', Stocks, Fleets, Obs, Imps, CatchFrac, Rel = Rel, nsim = nsim)
+#  plot(MOM_BH)
 
 ## ---- eval = TRUE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 
